API Reference
*************************************

.. toctree::
   :caption: API Reference
   :hidden:
   
   core/index
   utils/index


In this section, you can explore the API documentation for ParquetDB.


.. card:: core API
   :link: core-api-index
   :link-type: ref
   :class-title: parquetdb-card-title

   Learn more about ParquetDB's core functionality.


.. card:: utils API
   :link: utils-api-index
   :link-type: ref
   :class-title: parquetdb-card-title

   Learn more about ParquetDB's utility functions.

